@@ -67,25 +67,25 @@ mod sample_assets {
                     .unwrap()
                     .set_format(Format::R32G32B32_Float)
                     .set_input_slot(0)
-                    .set_offset(Bytes::from(offset_of!(Self, position))),
+                    .set_offset(ByteCount::from(offset_of!(Self, position))),
                 InputElementDesc::default()
                     .set_name("NORMAL")
                     .unwrap()
                     .set_format(Format::R32G32B32_Float)
                     .set_input_slot(0)
-                    .set_offset(Bytes::from(offset_of!(Self, normal))),
+                    .set_offset(ByteCount::from(offset_of!(Self, normal))),
                 InputElementDesc::default()
                     .set_name("TEXCOORD")
                     .unwrap()
                     .set_format(Format::R32G32_Float)
                     .set_input_slot(0)
-                    .set_offset(Bytes::from(offset_of!(Self, uv))),
+                    .set_offset(ByteCount::from(offset_of!(Self, uv))),
                 InputElementDesc::default()
                     .set_name("TANGENT")
                     .unwrap()
                     .set_format(Format::R32G32B32_Float)
                     .set_input_slot(0)
-                    .set_offset(Bytes::from(offset_of!(Self, tangent))),
+                    .set_offset(ByteCount::from(offset_of!(Self, tangent))),
             ]
         }
     }
@@ -157,11 +157,11 @@ mod sample_assets {
     pub const CITY_MATERIAL_TEXTURE_CHANNEL_COUNT: u32 = 4;
     pub const CITY_SPACING_INTERVAL: f32 = 16.;
 
-    pub const VERTEX_DATA_OFFSET: Bytes = Bytes(524288);
-    pub const VERTEX_DATA_SIZE: Bytes = Bytes(820248);
+    pub const VERTEX_DATA_OFFSET: ByteCount = ByteCount(524288);
+    pub const VERTEX_DATA_SIZE: ByteCount = ByteCount(820248);
 
-    pub const INDEX_DATA_OFFSET: Bytes = Bytes(1344536);
-    pub const INDEX_DATA_SIZE: Bytes = Bytes(74568);
+    pub const INDEX_DATA_OFFSET: ByteCount = ByteCount(1344536);
+    pub const INDEX_DATA_SIZE: ByteCount = ByteCount(74568);
 }
 
 use sample_assets::*;
@@ -206,6 +206,8 @@ struct DynamicIndexingSample {
     rtv_heap: DescriptorHeap,
     dsv_heap: DescriptorHeap,
     cbv_srv_heap: DescriptorHeap,
+    cbv_srv_descriptor_handle_size: ByteCount,
+    rtv_descriptor_handle_size: ByteCount,
     sampler_heap: DescriptorHeap,
     command_allocator: CommandAllocator,
     command_list: CommandList,
@@ -293,8 +295,16 @@ impl DynamicIndexingSample {
             .set_right(WINDOW_WIDTH as i32)
             .set_bottom(WINDOW_HEIGHT as i32);
 
+        let cbv_srv_descriptor_handle_size = device
+            .get_descriptor_handle_increment_size(
+                DescriptorHeapType::CbvSrvUav,
+            );
+
+        let rtv_descriptor_handle_size = device
+            .get_descriptor_handle_increment_size(DescriptorHeapType::Rtv);
+
         let (render_targets, rtv_heap, dsv_heap, cbv_srv_heap, sampler_heap) =
-            setup_heaps(&device, &swapchain);
+            setup_heaps(&device, &swapchain, rtv_descriptor_handle_size);
 
         let command_allocator = device
             .create_command_allocator(CommandListType::Direct)
@@ -349,6 +359,8 @@ impl DynamicIndexingSample {
             rtv_heap,
             dsv_heap,
             cbv_srv_heap,
+            cbv_srv_descriptor_handle_size,
+            rtv_descriptor_handle_size,
             sampler_heap,
             command_allocator,
             root_signature,
@@ -425,13 +437,16 @@ impl DynamicIndexingSample {
         let mut cbv_srv_handle = self
             .cbv_srv_heap
             .get_cpu_descriptor_handle_for_heap_start()
-            .advance((CITY_MATERIAL_COUNT + 1).into());
+            .advance(
+                (CITY_MATERIAL_COUNT + 1).into(),
+                self.cbv_srv_descriptor_handle_size,
+            );
 
         for frame_idx in 0..FRAMES_IN_FLIGHT {
             let mut frame_resource = FrameResource::new(&self.device);
 
-            let mut cb_offset = Bytes(0);
-            let cb_size = Bytes::from(size_of::<SceneConstantBuffer>());
+            let mut cb_offset = ByteCount(0);
+            let cb_size = ByteCount::from(size_of::<SceneConstantBuffer>());
 
             for _ in 0..CITY_ROW_COUNT {
                 for _ in 0..CITY_COLUMN_COUNT {
@@ -450,7 +465,8 @@ impl DynamicIndexingSample {
                     self.device
                         .create_constant_buffer_view(&cbv_desc, cbv_srv_handle);
 
-                    cbv_srv_handle = cbv_srv_handle.advance(1);
+                    cbv_srv_handle = cbv_srv_handle
+                        .advance(1, self.cbv_srv_descriptor_handle_size);
                 }
             }
 
@@ -468,6 +484,7 @@ impl DynamicIndexingSample {
                 &self.cbv_srv_heap,
                 &self.sampler_heap,
                 &self.root_signature,
+                self.cbv_srv_descriptor_handle_size,
             );
 
             self.frame_resources.push(frame_resource);
@@ -566,14 +583,14 @@ impl DynamicIndexingSample {
                 &self.mesh_data[VERTEX_DATA_OFFSET.into()
                     ..(VERTEX_DATA_OFFSET + VERTEX_DATA_SIZE).into()],
             )
-            .set_row_pitch(Bytes(VERTEX_DATA_SIZE.0))
-            .set_slice_pitch(Bytes(VERTEX_DATA_SIZE.0));
+            .set_row_pitch(ByteCount(VERTEX_DATA_SIZE.0))
+            .set_slice_pitch(ByteCount(VERTEX_DATA_SIZE.0));
 
         self.command_list
             .update_subresources_heap_alloc(
                 &vertex_buffer,
                 &vertex_staging_buffer,
-                Bytes(0),
+                ByteCount(0),
                 0,
                 1,
                 &[vertex_subresource_data],
@@ -595,10 +612,10 @@ impl DynamicIndexingSample {
         self.vertex_buffer_view = Some(
             VertexBufferView::default()
                 .set_buffer_location(vertex_buffer.get_gpu_virtual_address())
-                .set_size_in_bytes(Bytes::from(
+                .set_size_in_bytes(ByteCount::from(
                     vertex_count * size_of::<Vertex>() as u64,
                 ))
-                .set_stride_in_bytes(Bytes::from(size_of::<Vertex>())),
+                .set_stride_in_bytes(ByteCount::from(size_of::<Vertex>())),
         );
 
         self.vertex_buffer = Some(vertex_buffer);
@@ -653,14 +670,14 @@ impl DynamicIndexingSample {
                 &self.mesh_data[INDEX_DATA_OFFSET.into()
                     ..(INDEX_DATA_OFFSET + INDEX_DATA_SIZE).into()],
             )
-            .set_row_pitch(Bytes(INDEX_DATA_SIZE.0))
-            .set_slice_pitch(Bytes(INDEX_DATA_SIZE.0));
+            .set_row_pitch(ByteCount(INDEX_DATA_SIZE.0))
+            .set_slice_pitch(ByteCount(INDEX_DATA_SIZE.0));
 
         self.command_list
             .update_subresources_heap_alloc(
                 &index_buffer,
                 &index_staging_buffer,
-                Bytes(0),
+                ByteCount(0),
                 0,
                 1,
                 &[index_subresource_data],
@@ -680,7 +697,7 @@ impl DynamicIndexingSample {
         self.index_buffer_view = Some(
             IndexBufferView::default()
                 .set_buffer_location(index_buffer.get_gpu_virtual_address())
-                .set_size_in_bytes(self.index_count * Bytes(4))
+                .set_size_in_bytes(self.index_count * ByteCount(4))
                 .set_format(Format::R32_UInt),
         );
 
@@ -740,7 +757,7 @@ impl DynamicIndexingSample {
             self.cbv_srv_heap.get_cpu_descriptor_handle_for_heap_start(),
         );
 
-        srv_handle = srv_handle.advance(1);
+        srv_handle = srv_handle.advance(1, self.cbv_srv_descriptor_handle_size);
 
         for mat_idx in 0..CITY_MATERIAL_COUNT as usize {
             let mat_srv_desc =
@@ -757,7 +774,8 @@ impl DynamicIndexingSample {
                 srv_handle,
             );
 
-            srv_handle = srv_handle.advance(1);
+            srv_handle =
+                srv_handle.advance(1, self.cbv_srv_descriptor_handle_size);
         }
     }
 
@@ -825,7 +843,7 @@ impl DynamicIndexingSample {
             .update_subresources_heap_alloc(
                 &city_diffuse_texture,
                 &texture_staging_buffer,
-                Bytes(0),
+                ByteCount(0),
                 0,
                 subresource_count,
                 slice::from_ref(&texture_subresource_data),
@@ -859,7 +877,7 @@ impl DynamicIndexingSample {
             .expect("Cannot get upload buffer step");
 
         let upload_buffer_size =
-            Bytes::from(upload_buffer_step * CITY_MATERIAL_COUNT);
+            ByteCount::from(upload_buffer_step * CITY_MATERIAL_COUNT);
 
         let materials_staging_buffer = self
             .device
@@ -881,11 +899,11 @@ impl DynamicIndexingSample {
         for mat_idx in 0..CITY_MATERIAL_COUNT as usize {
             let texture_subresource_data = SubresourceData::default()
                 .set_data(&texture_data[mat_idx])
-                .set_row_pitch(Bytes(
+                .set_row_pitch(ByteCount(
                     CITY_MATERIAL_TEXTURE_CHANNEL_COUNT as u64
                         * texture_desc.0.Width,
                 ))
-                .set_slice_pitch(Bytes(
+                .set_slice_pitch(ByteCount(
                     CITY_MATERIAL_TEXTURE_CHANNEL_COUNT as u64
                         * texture_desc.0.Width
                         * texture_desc.0.Height as u64,
@@ -895,7 +913,7 @@ impl DynamicIndexingSample {
                 .update_subresources_heap_alloc(
                     &self.city_material_textures[mat_idx],
                     &materials_staging_buffer,
-                    Bytes(mat_idx as u64 * upload_buffer_step.0),
+                    ByteCount(mat_idx as u64 * upload_buffer_step.0),
                     0,
                     subresource_count,
                     slice::from_ref(&texture_subresource_data),
@@ -1023,7 +1041,10 @@ impl DynamicIndexingSample {
         let mut rtv_handle = self
             .rtv_heap
             .get_cpu_descriptor_handle_for_heap_start()
-            .advance(self.frame_index.into());
+            .advance(
+                self.frame_index.into(),
+                self.cbv_srv_descriptor_handle_size,
+            );
 
         let dsv_handle =
             self.dsv_heap.get_cpu_descriptor_handle_for_heap_start();
@@ -1073,6 +1094,7 @@ impl DynamicIndexingSample {
                     &self.cbv_srv_heap,
                     &self.sampler_heap,
                     &self.root_signature,
+                    self.cbv_srv_descriptor_handle_size,
                 );
         }
 
@@ -1205,7 +1227,9 @@ fn create_pipeline_state(
         .set_root_signature(root_signature)
         .set_vs_bytecode(&vs_bytecode)
         .set_ps_bytecode(&ps_bytecode)
-        .set_rasterizer_state(&RasterizerDesc::default())
+        .set_rasterizer_state(
+            &RasterizerDesc::default().set_cull_mode(CullMode::None),
+        )
         .set_blend_state(&BlendDesc::default())
         .set_depth_stencil_state(&DepthStencilDesc::default())
         .set_primitive_topology_type(PrimitiveTopologyType::Triangle)
@@ -1364,6 +1388,7 @@ d3dx12.h as a dependency to have DX12SerializeVersionedRootSignature"
 fn setup_heaps(
     device: &Device,
     swapchain: &Swapchain,
+    rtv_descriptor_handle_size: ByteCount,
 ) -> (
     Vec<Resource>,
     DescriptorHeap,
@@ -1432,7 +1457,7 @@ fn setup_heaps(
         device.create_render_target_view(&render_target, rtv_handle);
         render_targets.push(render_target);
 
-        rtv_handle = rtv_handle.advance(1);
+        rtv_handle = rtv_handle.advance(1, rtv_descriptor_handle_size);
     }
 
     (
@@ -1577,6 +1602,7 @@ impl FrameResource {
         cbv_srv_descriptor_heap: &DescriptorHeap,
         sampler_descriptor_heap: &DescriptorHeap,
         root_signature: &RootSignature,
+        cbv_srv_descriptor_handle_size: ByteCount,
     ) {
         let bundle = device
             .create_command_list(
@@ -1599,6 +1625,7 @@ impl FrameResource {
             cbv_srv_descriptor_heap,
             sampler_descriptor_heap,
             root_signature,
+            cbv_srv_descriptor_handle_size,
         );
 
         bundle.close().expect("Cannot close bundle");
@@ -1616,6 +1643,7 @@ impl FrameResource {
         cbv_srv_descriptor_heap: &DescriptorHeap,
         sampler_descriptor_heap: &DescriptorHeap,
         root_signature: &RootSignature,
+        cbv_srv_descriptor_handle_size: ByteCount,
     ) {
         let mut heaps = [
             cbv_srv_descriptor_heap.clone(),
@@ -1641,7 +1669,10 @@ impl FrameResource {
 
         let mut cbv_srv_handle = cbv_srv_descriptor_heap
             .get_gpu_descriptor_handle_for_heap_start()
-            .advance(u32::from(frame_resource_descriptor_offset));
+            .advance(
+                u32::from(frame_resource_descriptor_offset),
+                cbv_srv_descriptor_handle_size,
+            );
 
         for i in 0..CITY_ROW_COUNT {
             for j in 0..CITY_COLUMN_COUNT {
@@ -1654,7 +1685,8 @@ impl FrameResource {
                 command_list
                     .set_graphics_root_descriptor_table(1, cbv_srv_handle);
 
-                cbv_srv_handle = cbv_srv_handle.advance(1);
+                cbv_srv_handle =
+                    cbv_srv_handle.advance(1, cbv_srv_descriptor_handle_size);
 
                 command_list.draw_indexed_instanced(num_indices, 1, 0, 0, 0);
             }
