@@ -76,7 +76,7 @@ impl Vertex {
             .unwrap()
             .set_format(Format::R32G32B32_Float)
             .set_input_slot(0)
-            .set_offset(Bytes(offset_of!(Self, position) as u64))]
+            .set_offset(ByteCount(offset_of!(Self, position) as u64))]
     }
 }
 
@@ -120,6 +120,7 @@ struct HelloMeshShadersSample {
     scissor_desc: Rect,
     render_targets: Vec<Resource>,
     rtv_heap: DescriptorHeap,
+    rtv_descriptor_handle_size: ByteCount,
     dsv_heap: DescriptorHeap,
     command_allocators: Vec<CommandAllocator>,
     command_list: CommandList,
@@ -199,8 +200,11 @@ impl HelloMeshShadersSample {
             .set_right(WINDOW_WIDTH as i32)
             .set_bottom(WINDOW_HEIGHT as i32);
 
+        let rtv_descriptor_handle_size = device
+            .get_descriptor_handle_increment_size(DescriptorHeapType::Rtv);
+
         let (render_targets, rtv_heap, dsv_heap) =
-            setup_heaps(&device, &swapchain);
+            setup_heaps(&device, &swapchain, rtv_descriptor_handle_size);
 
         trace!("Created heaps and render targets");
 
@@ -255,6 +259,7 @@ impl HelloMeshShadersSample {
             scissor_desc,
             render_targets,
             rtv_heap,
+            rtv_descriptor_handle_size,
             dsv_heap,
             command_allocators,
             root_signature,
@@ -329,7 +334,7 @@ impl HelloMeshShadersSample {
             .reset(&self.command_allocators[0], None)
             .expect("Cannot reset command lsit");
 
-        let size = Bytes::from(init_data.len() * std::mem::size_of::<T>());
+        let size = ByteCount::from(init_data.len() * std::mem::size_of::<T>());
         let staging_buffer = self
             .device
             .create_committed_resource(
@@ -389,9 +394,9 @@ impl HelloMeshShadersSample {
 
         self.command_list.copy_buffer_region(
             &default_buffer,
-            Bytes(0),
+            ByteCount(0),
             &staging_buffer,
-            Bytes(0),
+            ByteCount(0),
             size,
         );
 
@@ -462,25 +467,26 @@ impl HelloMeshShadersSample {
                 .get_gpu_virtual_address(),
         );
 
-        self.command_list.set_viewports(&vec![self.viewport_desc]);
-        self.command_list
-            .set_scissor_rects(&vec![self.scissor_desc]);
+        self.command_list.set_viewports(&[self.viewport_desc]);
+        self.command_list.set_scissor_rects(&[self.scissor_desc]);
 
-        self.command_list.resource_barrier(&vec![
-            ResourceBarrier::new_transition(
+        self.command_list
+            .resource_barrier(&[ResourceBarrier::new_transition(
                 &ResourceTransitionBarrier::default()
                     .set_resource(
                         &self.render_targets[self.frame_index as usize],
                     )
                     .set_state_before(ResourceStates::Common)
                     .set_state_after(ResourceStates::RenderTarget),
-            ),
-        ]);
+            )]);
 
         let rtv_handle = self
             .rtv_heap
             .get_cpu_descriptor_handle_for_heap_start()
-            .advance(self.swapchain.get_current_back_buffer_index());
+            .advance(
+                self.swapchain.get_current_back_buffer_index(),
+                self.rtv_descriptor_handle_size,
+            );
 
         self.command_list.set_render_targets(
             &mut [rtv_handle],
@@ -689,19 +695,21 @@ fn create_pipeline_state(
 
     let pso_subobjects_desc = MeshShaderPipelineStateDesc::default()
         .set_root_signature(root_signature)
-        .set_mesh_shader_bytecode(&ms_bytecode)
+        .set_ms_bytecode(&ms_bytecode)
         .set_ps_bytecode(&ps_bytecode)
         .set_rasterizer_state(
-            &RasterizerDesc::default().set_cull_mode(CullMode::Back),
+            &RasterizerDesc::default().set_depth_clip_enable(false),
         )
         .set_blend_state(&BlendDesc::default())
-        .set_depth_stencil_state(&DepthStencilDesc::default())
+        .set_depth_stencil_state(
+            &DepthStencilDesc::default().set_depth_enable(false),
+        )
         .set_primitive_topology_type(PrimitiveTopologyType::Triangle)
         .set_rtv_formats(&[Format::R8G8B8A8_UNorm]);
 
     let pso_desc = PipelineStateStreamDesc::default()
         .set_pipeline_state_subobject_stream(
-            pso_subobjects_desc.make_byte_stream(),
+            pso_subobjects_desc.as_byte_stream(),
         );
 
     let pso = device
@@ -751,6 +759,7 @@ fn setup_root_signature(
 fn setup_heaps(
     device: &Device,
     swapchain: &Swapchain,
+    rtv_descriptor_handle_size: ByteCount,
 ) -> (Vec<Resource>, DescriptorHeap, DescriptorHeap) {
     let rtv_heap = device
         .create_descriptor_heap(
@@ -785,7 +794,7 @@ fn setup_heaps(
         device.create_render_target_view(&render_target, rtv_handle);
         render_targets.push(render_target);
 
-        rtv_handle = rtv_handle.advance(1);
+        rtv_handle = rtv_handle.advance(1, rtv_descriptor_handle_size);
     }
 
     (render_targets, rtv_heap, dsv_heap)
@@ -832,7 +841,7 @@ fn insert_unique(coll: &mut Vec<u32>, value: u32) -> u32 {
         pos as u32
     } else {
         coll.push(value);
-        return (coll.len() - 1) as u32;
+        (coll.len() - 1) as u32
     }
 }
 
