@@ -57,13 +57,13 @@ impl Vertex {
                 .unwrap()
                 .set_format(Format::R32G32B32_Float)
                 .set_input_slot(0)
-                .set_offset(Bytes(offset_of!(Self, position) as u64)),
+                .set_offset(ByteCount(offset_of!(Self, position) as u64)),
             InputElementDesc::default()
                 .set_name("Color")
                 .unwrap()
                 .set_format(Format::R32G32B32A32_Float)
                 .set_input_slot(0)
-                .set_offset(Bytes(offset_of!(Self, color) as u64)),
+                .set_offset(ByteCount(offset_of!(Self, color) as u64)),
         ]
     }
 }
@@ -73,14 +73,14 @@ trait TypedBuffer {
     fn from_resource(
         resource: Resource,
         element_count: u32,
-        element_size: Bytes,
+        element_size: ByteCount,
     ) -> Self;
 }
 
 struct VertexBuffer {
     buffer: Resource,
     view: VertexBufferView,
-    size: Bytes,
+    size: ByteCount,
 }
 
 impl TypedBuffer for VertexBuffer {
@@ -90,7 +90,7 @@ impl TypedBuffer for VertexBuffer {
     fn from_resource(
         buffer: Resource,
         element_count: u32,
-        element_size: Bytes,
+        element_size: ByteCount,
     ) -> Self {
         let size = element_size * element_count;
         let view = VertexBufferView::default()
@@ -108,7 +108,7 @@ impl TypedBuffer for VertexBuffer {
 struct IndexBuffer {
     buffer: Resource,
     view: IndexBufferView,
-    size: Bytes,
+    size: ByteCount,
 }
 
 impl TypedBuffer for IndexBuffer {
@@ -117,15 +117,15 @@ impl TypedBuffer for IndexBuffer {
     fn from_resource(
         buffer: Resource,
         element_count: u32,
-        element_size: Bytes,
+        element_size: ByteCount,
     ) -> Self {
         let size = element_size * element_count;
         let view = IndexBufferView::default()
             .set_buffer_location(buffer.get_gpu_virtual_address())
             .set_size_in_bytes(element_count * element_size)
             .set_format(match element_size {
-                Bytes(2) => Format::R16_UInt,
-                Bytes(4) => Format::R32_UInt,
+                ByteCount(2) => Format::R16_UInt,
+                ByteCount(4) => Format::R32_UInt,
                 _ => panic!("wrong index type"),
             });
 
@@ -144,7 +144,7 @@ struct HelloTriangleSample {
     vertex_buffers: Vec<VertexBuffer>,
     current_frame: u64,
     current_fence_value: u64,
-    rtv_descriptor_size: u32,
+    rtv_descriptor_size: ByteCount,
     rtv_heap: DescriptorHeap,
     swapchain: Swapchain,
     command_list: CommandList,
@@ -237,7 +237,7 @@ impl HelloTriangleSample {
             device: device,
             info_queue: info_queue,
             fence: fence,
-            rtv_descriptor_size: rtv_descriptor_size,
+            rtv_descriptor_size,
             command_queue: command_queue,
             command_allocator: command_allocator,
             command_list: command_list,
@@ -348,7 +348,9 @@ float4 PS(VertexOut input) : SV_Target
             .set_ps_bytecode(&pixel_bytecode)
             .set_blend_state(&BlendDesc::default())
             .set_rasterizer_state(&RasterizerDesc::default())
-            .set_depth_stencil_state(&DepthStencilDesc::default())
+            .set_depth_stencil_state(
+                &DepthStencilDesc::default().set_depth_enable(false),
+            )
             .set_input_layout(&input_layout)
             .set_primitive_topology_type(PrimitiveTopologyType::Triangle)
             .set_rtv_formats(&[Format::R8G8B8A8_UNorm])
@@ -387,7 +389,7 @@ float4 PS(VertexOut input) : SV_Target
         let rtv_handle = self
             .rtv_heap
             .get_cpu_descriptor_handle_for_heap_start()
-            .advance(current_buffer_index);
+            .advance(current_buffer_index, self.rtv_descriptor_size);
 
         HelloTriangleSample::add_transition(
             &self.command_list,
@@ -481,7 +483,7 @@ impl HelloTriangleSample {
             let rtv_handle = self
                 .rtv_heap
                 .get_cpu_descriptor_handle_for_heap_start()
-                .advance(buffer_index);
+                .advance(buffer_index, self.rtv_descriptor_size);
             let buffer = self
                 .swapchain
                 .get_buffer(buffer_index)
@@ -493,7 +495,7 @@ impl HelloTriangleSample {
     fn create_buffer(
         &self,
         device: &Device,
-        size: Bytes,
+        size: ByteCount,
         heap_type: HeapType,
         initial_state: ResourceStates,
     ) -> DxResult<Resource> {
@@ -538,7 +540,7 @@ impl HelloTriangleSample {
             .reset(&self.command_allocator, None)
             .expect("Cannot reset command lsit");
 
-        let size = Bytes::from(
+        let size = ByteCount::from(
             init_data.len() * std::mem::size_of::<T::ElementType>(),
         );
         let staging_buffer = self
@@ -593,9 +595,9 @@ impl HelloTriangleSample {
 
         self.command_list.copy_buffer_region(
             &default_buffer,
-            Bytes(0),
+            ByteCount(0),
             &staging_buffer,
-            Bytes(0),
+            ByteCount(0),
             size,
         );
 
@@ -617,7 +619,7 @@ impl HelloTriangleSample {
         Ok(T::from_resource(
             default_buffer,
             init_data.len() as u32,
-            Bytes::from(std::mem::size_of::<T::ElementType>()),
+            ByteCount::from(std::mem::size_of::<T::ElementType>()),
         ))
     }
 
