@@ -125,13 +125,13 @@ impl Vertex {
                 .unwrap()
                 .set_format(Format::R32G32B32A32_Float)
                 .set_input_slot(0)
-                .set_offset(Bytes::from(offset_of!(Self, position))),
+                .set_offset(ByteCount::from(offset_of!(Self, position))),
             InputElementDesc::default()
                 .set_name("COLOR")
                 .unwrap()
                 .set_format(Format::R32G32B32A32_Float)
                 .set_input_slot(0)
-                .set_offset(Bytes::from(offset_of!(Self, color))),
+                .set_offset(ByteCount::from(offset_of!(Self, color))),
         ]
     }
 }
@@ -185,7 +185,9 @@ struct Pipeline {
     viewport: Viewport,
     scissor_rect: Rect,
     rtv_heap: DescriptorHeap,
+    rtv_descriptor_handle_size: ByteCount,
     cbv_srv_heap: DescriptorHeap,
+    cbv_srv_descriptor_handle_size: ByteCount,
     render_targets: Vec<Resource>,
     direct_command_allocators: Vec<CommandAllocator>,
     shared_heap: Heap,
@@ -292,7 +294,14 @@ impl Pipeline {
             create_descriptor_heaps(&device, &swapchain);
 
         let (render_targets, direct_command_allocators) =
-            create_frame_resources(&device, &rtv_heap, &swapchain);
+            create_frame_resources(
+                &device,
+                &rtv_heap,
+                &swapchain,
+                device.get_descriptor_handle_increment_size(
+                    DescriptorHeapType::Rtv,
+                ),
+            );
 
         let (texture_size, cross_adapter_desc) =
             create_shared_resource_desc(&device);
@@ -399,6 +408,14 @@ impl Pipeline {
 
         trace!("Executed command lists");
 
+        let rtv_descriptor_handle_size = device
+            .get_descriptor_handle_increment_size(DescriptorHeapType::Rtv);
+
+        let cbv_srv_descriptor_handle_size = device
+            .get_descriptor_handle_increment_size(
+                DescriptorHeapType::CbvSrvUav,
+            );
+
         Self {
             is_producer_process,
             device,
@@ -410,7 +427,9 @@ impl Pipeline {
             viewport,
             scissor_rect,
             rtv_heap,
+            rtv_descriptor_handle_size,
             cbv_srv_heap,
+            cbv_srv_descriptor_handle_size,
             render_targets,
             direct_command_allocators,
             shared_heap,
@@ -467,7 +486,7 @@ impl Pipeline {
         let rtv_handle = self
             .rtv_heap
             .get_cpu_descriptor_handle_for_heap_start()
-            .advance(self.frame_index as u32);
+            .advance(self.frame_index as u32, self.rtv_descriptor_handle_size);
 
         self.direct_command_list.set_render_targets(
             slice::from_ref(&rtv_handle),
@@ -595,7 +614,7 @@ impl Pipeline {
         let rtv_handle = self
             .rtv_heap
             .get_cpu_descriptor_handle_for_heap_start()
-            .advance(self.frame_index as u32);
+            .advance(self.frame_index as u32, self.rtv_descriptor_handle_size);
 
         self.direct_command_list.set_render_targets(
             slice::from_ref(&rtv_handle),
@@ -768,7 +787,7 @@ fn create_scene_constant_buffer(
     is_producer_process: bool,
 ) -> Resource {
     let constant_buffer_size =
-        Bytes::from(size_of::<SceneConstantBuffer>() as u32);
+        ByteCount::from(size_of::<SceneConstantBuffer>() as u32);
 
     let constant_buffer = device
         .create_committed_resource(
@@ -829,7 +848,7 @@ fn create_vertex_buffer(
     ];
 
     let vertex_buffer_size =
-        Bytes::from(triangle_vertices.len() * size_of::<Vertex>());
+        ByteCount::from(triangle_vertices.len() * size_of::<Vertex>());
 
     let vertex_buffer = device
         .create_committed_resource(
@@ -872,7 +891,7 @@ fn create_vertex_buffer(
         .update_subresources_heap_alloc(
             &vertex_buffer,
             &vertex_buffer_upload,
-            Bytes(0),
+            ByteCount(0),
             0,
             1,
             slice::from_ref(&vertex_data),
@@ -891,7 +910,7 @@ fn create_vertex_buffer(
 
     let vertex_buffer_view = VertexBufferView::default()
         .set_buffer_location(vertex_buffer.get_gpu_virtual_address())
-        .set_stride_in_bytes(Bytes::from(std::mem::size_of::<Vertex>()))
+        .set_stride_in_bytes(ByteCount::from(std::mem::size_of::<Vertex>()))
         .set_size_in_bytes(vertex_buffer_size);
     trace!("Created primary adapter vertex buffer");
 
@@ -952,7 +971,9 @@ fn create_pso(
         .set_ps_bytecode(&ps_bytecode)
         .set_rasterizer_state(&RasterizerDesc::default())
         .set_blend_state(&BlendDesc::default())
-        .set_depth_stencil_state(&DepthStencilDesc::default())
+        .set_depth_stencil_state(
+            &DepthStencilDesc::default().set_depth_enable(false),
+        )
         .set_primitive_topology_type(PrimitiveTopologyType::Triangle)
         .set_rtv_formats(&[Format::R8G8B8A8_UNorm])
         .set_dsv_format(Format::D32_Float);
@@ -1003,8 +1024,8 @@ fn create_root_signature(device: &Device) -> RootSignature {
     root_signature
 }
 
-fn create_shared_resource_desc(device: &Device) -> (Bytes, ResourceDesc) {
-    let texture_size: Bytes;
+fn create_shared_resource_desc(device: &Device) -> (ByteCount, ResourceDesc) {
+    let texture_size: ByteCount;
     let cross_adapter_desc = ResourceDesc::default()
         .set_dimension(ResourceDimension::Texture2D)
         .set_layout(TextureLayout::RowMajor)
@@ -1018,7 +1039,7 @@ fn create_shared_resource_desc(device: &Device) -> (Bytes, ResourceDesc) {
 
     texture_size = align_to_multiple(
         (layout[0].0.Footprint.RowPitch * layout[0].0.Footprint.Height) as u64,
-        DEFAULT_RESOURCE_ALIGNMENT.0,
+        DEFAULT_RESOURCE_PLACEMENT_ALIGNMENT.0,
     )
     .into();
 
@@ -1029,6 +1050,7 @@ fn create_frame_resources(
     device: &Device,
     rtv_heap: &DescriptorHeap,
     swapchain: &Swapchain,
+    rtv_descriptor_handle_size: ByteCount,
 ) -> (Vec<Resource>, Vec<CommandAllocator>) {
     let clear_value = ClearValue::default()
         .set_format(Format::R8G8B8A8_UNorm)
@@ -1057,7 +1079,7 @@ fn create_frame_resources(
         device
             .create_render_target_view(&render_targets[frame_idx], rtv_handle);
 
-        rtv_handle = rtv_handle.advance(1);
+        rtv_handle = rtv_handle.advance(1, rtv_descriptor_handle_size);
 
         direct_command_allocators.push(
             device
