@@ -7,13 +7,6 @@ use crate::utils::*;
 // use crate::{enum_wrappers::*};
 // use crate::{struct_wrappers::*};
 
-// ToDo: keep the original name?
-pub const CONSTANT_BUFFER_ALIGNMENT: Bytes =
-    Bytes(D3D12_CONSTANT_BUFFER_DATA_PLACEMENT_ALIGNMENT as u64);
-
-pub const DEFAULT_RESOURCE_ALIGNMENT: Bytes =
-    Bytes(D3D12_DEFAULT_RESOURCE_PLACEMENT_ALIGNMENT as u64);
-
 pub const STANDARD_MULTISAMPLE_QUALITY_PATTERN: u32 =
     DXGI_STANDARD_MULTISAMPLE_QUALITY_PATTERN;
 pub const CENTER_MULTISAMPLE_QUALITY_PATTERN: u32 =
@@ -92,8 +85,8 @@ pub const COMMONSHADER_TEXEL_OFFSET_MAX_NEGATIVE: i32 =
     D3D12_COMMONSHADER_TEXEL_OFFSET_MAX_NEGATIVE;
 pub const COMMONSHADER_TEXEL_OFFSET_MAX_POSITIVE: u32 =
     D3D12_COMMONSHADER_TEXEL_OFFSET_MAX_POSITIVE;
-pub const CONSTANT_BUFFER_DATA_PLACEMENT_ALIGNMENT: Bytes =
-    Bytes(D3D12_CONSTANT_BUFFER_DATA_PLACEMENT_ALIGNMENT as u64);
+pub const CONSTANT_BUFFER_DATA_PLACEMENT_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_CONSTANT_BUFFER_DATA_PLACEMENT_ALIGNMENT as u64);
 pub const CS_4_X_BUCKET00_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: u32 =
     D3D12_CS_4_X_BUCKET00_MAX_BYTES_TGSM_WRITABLE_PER_THREAD;
 pub const CS_4_X_BUCKET00_MAX_NUM_THREADS_PER_GROUP: u32 =
@@ -160,8 +153,8 @@ pub const CS_4_X_BUCKET15_MAX_NUM_THREADS_PER_GROUP: u32 =
     D3D12_CS_4_X_BUCKET15_MAX_NUM_THREADS_PER_GROUP;
 pub const CS_4_X_DISPATCH_MAX_THREAD_GROUPS_IN_Z_DIMENSION: u32 =
     D3D12_CS_4_X_DISPATCH_MAX_THREAD_GROUPS_IN_Z_DIMENSION;
-pub const CS_4_X_RAW_UAV_BYTE_ALIGNMENT: Bytes =
-    Bytes(D3D12_CS_4_X_RAW_UAV_BYTE_ALIGNMENT as u64);
+pub const CS_4_X_RAW_UAV_BYTE_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_CS_4_X_RAW_UAV_BYTE_ALIGNMENT as u64);
 pub const CS_4_X_THREAD_GROUP_MAX_THREADS_PER_GROUP: u32 =
     D3D12_CS_4_X_THREAD_GROUP_MAX_THREADS_PER_GROUP;
 pub const CS_4_X_THREAD_GROUP_MAX_X: u32 = D3D12_CS_4_X_THREAD_GROUP_MAX_X;
@@ -211,12 +204,12 @@ pub const DEFAULT_DEPTH_BIAS: u32 = D3D12_DEFAULT_DEPTH_BIAS;
 pub const DEFAULT_DEPTH_BIAS_CLAMP: f64 = D3D12_DEFAULT_DEPTH_BIAS_CLAMP;
 pub const DEFAULT_MAX_ANISOTROPY: u32 = D3D12_DEFAULT_MAX_ANISOTROPY;
 pub const DEFAULT_MIP_LOD_BIAS: f64 = D3D12_DEFAULT_MIP_LOD_BIAS;
-pub const DEFAULT_MSAA_RESOURCE_PLACEMENT_ALIGNMENT: Bytes =
-    Bytes(D3D12_DEFAULT_MSAA_RESOURCE_PLACEMENT_ALIGNMENT as u64);
+pub const DEFAULT_MSAA_RESOURCE_PLACEMENT_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_DEFAULT_MSAA_RESOURCE_PLACEMENT_ALIGNMENT as u64);
 pub const DEFAULT_RENDER_TARGET_ARRAY_INDEX: u32 =
     D3D12_DEFAULT_RENDER_TARGET_ARRAY_INDEX;
-pub const DEFAULT_RESOURCE_PLACEMENT_ALIGNMENT: Bytes =
-    Bytes(D3D12_DEFAULT_RESOURCE_PLACEMENT_ALIGNMENT as u64);
+pub const DEFAULT_RESOURCE_PLACEMENT_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_DEFAULT_RESOURCE_PLACEMENT_ALIGNMENT as u64);
 pub const DEFAULT_SAMPLE_MASK: u32 = D3D12_DEFAULT_SAMPLE_MASK;
 pub const DEFAULT_SCISSOR_ENDX: u32 = D3D12_DEFAULT_SCISSOR_ENDX;
 pub const DEFAULT_SCISSOR_ENDY: u32 = D3D12_DEFAULT_SCISSOR_ENDY;
@@ -411,12 +404,12 @@ pub const HS_OUTPUT_PATCH_CONSTANT_REGISTER_READ_PORTS: u32 =
     D3D12_HS_OUTPUT_PATCH_CONSTANT_REGISTER_READ_PORTS;
 pub const HS_OUTPUT_PATCH_CONSTANT_REGISTER_SCALAR_COMPONENTS: u32 =
     D3D12_HS_OUTPUT_PATCH_CONSTANT_REGISTER_SCALAR_COMPONENTS;
-pub const IA_DEFAULT_INDEX_BUFFER_OFFSET: Bytes =
-    Bytes(D3D12_IA_DEFAULT_INDEX_BUFFER_OFFSET_IN_BYTES as u64);
+pub const IA_DEFAULT_INDEX_BUFFER_OFFSET: ByteCount =
+    ByteCount(D3D12_IA_DEFAULT_INDEX_BUFFER_OFFSET_IN_BYTES as u64);
 pub const IA_DEFAULT_PRIMITIVE_TOPOLOGY: u32 =
     D3D12_IA_DEFAULT_PRIMITIVE_TOPOLOGY;
-pub const IA_DEFAULT_VERTEX_BUFFER_OFFSET: Bytes =
-    Bytes(D3D12_IA_DEFAULT_VERTEX_BUFFER_OFFSET_IN_BYTES as u64);
+pub const IA_DEFAULT_VERTEX_BUFFER_OFFSET: ByteCount =
+    ByteCount(D3D12_IA_DEFAULT_VERTEX_BUFFER_OFFSET_IN_BYTES as u64);
 pub const IA_INDEX_INPUT_RESOURCE_SLOT_COUNT: u32 =
     D3D12_IA_INDEX_INPUT_RESOURCE_SLOT_COUNT;
 pub const IA_INSTANCE_ID_BIT_COUNT: u32 = D3D12_IA_INSTANCE_ID_BIT_COUNT;
@@ -520,28 +513,28 @@ pub const PS_OUTPUT_REGISTER_COMPONENT_BIT_COUNT: u32 =
 pub const PS_OUTPUT_REGISTER_COUNT: u32 = D3D12_PS_OUTPUT_REGISTER_COUNT;
 pub const PS_PIXEL_CENTER_FRACTIONAL_COMPONENT: f64 =
     D3D12_PS_PIXEL_CENTER_FRACTIONAL_COMPONENT;
-pub const RAW_UAV_SRV_BYTE_ALIGNMENT: Bytes =
-    Bytes(D3D12_RAW_UAV_SRV_BYTE_ALIGNMENT as u64);
-pub const RAYTRACING_AABB_BYTE_ALIGNMENT: Bytes =
-    Bytes(D3D12_RAYTRACING_AABB_BYTE_ALIGNMENT as u64);
-pub const RAYTRACING_ACCELERATION_STRUCTURE_BYTE_ALIGNMENT: Bytes =
-    Bytes(D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BYTE_ALIGNMENT as u64);
-pub const RAYTRACING_INSTANCE_DESCS_BYTE_ALIGNMENT: Bytes =
-    Bytes(D3D12_RAYTRACING_INSTANCE_DESCS_BYTE_ALIGNMENT as u64);
-pub const RAYTRACING_MAX_ATTRIBUTE_SIZE: Bytes =
-    Bytes(D3D12_RAYTRACING_MAX_ATTRIBUTE_SIZE_IN_BYTES as u64);
+pub const RAW_UAV_SRV_BYTE_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_RAW_UAV_SRV_BYTE_ALIGNMENT as u64);
+pub const RAYTRACING_AABB_BYTE_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_RAYTRACING_AABB_BYTE_ALIGNMENT as u64);
+pub const RAYTRACING_ACCELERATION_STRUCTURE_BYTE_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BYTE_ALIGNMENT as u64);
+pub const RAYTRACING_INSTANCE_DESCS_BYTE_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_RAYTRACING_INSTANCE_DESCS_BYTE_ALIGNMENT as u64);
+pub const RAYTRACING_MAX_ATTRIBUTE_SIZE: ByteCount =
+    ByteCount(D3D12_RAYTRACING_MAX_ATTRIBUTE_SIZE_IN_BYTES as u64);
 pub const RAYTRACING_MAX_DECLARABLE_TRACE_RECURSION_DEPTH: u32 =
     D3D12_RAYTRACING_MAX_DECLARABLE_TRACE_RECURSION_DEPTH;
 pub const RAYTRACING_MAX_RAY_GENERATION_SHADER_THREADS: u32 =
     D3D12_RAYTRACING_MAX_RAY_GENERATION_SHADER_THREADS;
 pub const RAYTRACING_MAX_SHADER_RECORD_STRIDE: u32 =
     D3D12_RAYTRACING_MAX_SHADER_RECORD_STRIDE;
-pub const RAYTRACING_SHADER_RECORD_BYTE_ALIGNMENT: Bytes =
-    Bytes(D3D12_RAYTRACING_SHADER_RECORD_BYTE_ALIGNMENT as u64);
-pub const RAYTRACING_SHADER_TABLE_BYTE_ALIGNMENT: Bytes =
-    Bytes(D3D12_RAYTRACING_SHADER_TABLE_BYTE_ALIGNMENT as u64);
-pub const RAYTRACING_TRANSFORM3X4_BYTE_ALIGNMENT: Bytes =
-    Bytes(D3D12_RAYTRACING_TRANSFORM3X4_BYTE_ALIGNMENT as u64);
+pub const RAYTRACING_SHADER_RECORD_BYTE_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_RAYTRACING_SHADER_RECORD_BYTE_ALIGNMENT as u64);
+pub const RAYTRACING_SHADER_TABLE_BYTE_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_RAYTRACING_SHADER_TABLE_BYTE_ALIGNMENT as u64);
+pub const RAYTRACING_TRANSFORM3X4_BYTE_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_RAYTRACING_TRANSFORM3X4_BYTE_ALIGNMENT as u64);
 pub const REQ_BLEND_OBJECT_COUNT_PER_DEVICE: u32 =
     D3D12_REQ_BLEND_OBJECT_COUNT_PER_DEVICE;
 pub const REQ_BUFFER_RESOURCE_TEXEL_COUNT_2_TO_EXP: u32 =
@@ -562,8 +555,8 @@ pub const REQ_IMMEDIATE_CONSTANT_BUFFER_ELEMENT_COUNT: u32 =
     D3D12_REQ_IMMEDIATE_CONSTANT_BUFFER_ELEMENT_COUNT;
 pub const REQ_MAXANISOTROPY: u32 = D3D12_REQ_MAXANISOTROPY;
 pub const REQ_MIP_LEVELS: u32 = D3D12_REQ_MIP_LEVELS;
-pub const REQ_MULTI_ELEMENT_STRUCTURE_SIZE: Bytes =
-    Bytes(D3D12_REQ_MULTI_ELEMENT_STRUCTURE_SIZE_IN_BYTES as u64);
+pub const REQ_MULTI_ELEMENT_STRUCTURE_SIZE: ByteCount =
+    ByteCount(D3D12_REQ_MULTI_ELEMENT_STRUCTURE_SIZE_IN_BYTES as u64);
 pub const REQ_RASTERIZER_OBJECT_COUNT_PER_DEVICE: u32 =
     D3D12_REQ_RASTERIZER_OBJECT_COUNT_PER_DEVICE;
 pub const REQ_RENDER_TO_BUFFER_WINDOW_WIDTH: u32 =
@@ -596,8 +589,8 @@ pub const RESOURCE_BARRIER_ALL_SUBRESOURCES: u32 =
 pub const RS_SET_SHADING_RATE_COMBINER_COUNT: u32 =
     D3D12_RS_SET_SHADING_RATE_COMBINER_COUNT;
 pub const SDK_VERSION: u32 = D3D12_SDK_VERSION;
-pub const SHADER_IDENTIFIER_SIZE: Bytes =
-    Bytes(D3D12_SHADER_IDENTIFIER_SIZE_IN_BYTES as u64);
+pub const SHADER_IDENTIFIER_SIZE: ByteCount =
+    ByteCount(D3D12_SHADER_IDENTIFIER_SIZE_IN_BYTES as u64);
 pub const SHADER_MAJOR_VERSION: u32 = D3D12_SHADER_MAJOR_VERSION;
 pub const SHADER_MAX_INSTANCES: u32 = D3D12_SHADER_MAX_INSTANCES;
 pub const SHADER_MAX_INTERFACES: u32 = D3D12_SHADER_MAX_INTERFACES;
@@ -610,14 +603,14 @@ pub const SHIFT_INSTRUCTION_SHIFT_VALUE_BIT_COUNT: u32 =
     D3D12_SHIFT_INSTRUCTION_SHIFT_VALUE_BIT_COUNT;
 pub const SIMULTANEOUS_RENDER_TARGET_COUNT: u32 =
     D3D12_SIMULTANEOUS_RENDER_TARGET_COUNT;
-pub const SMALL_MSAA_RESOURCE_PLACEMENT_ALIGNMENT: Bytes =
-    Bytes(D3D12_SMALL_MSAA_RESOURCE_PLACEMENT_ALIGNMENT as u64);
-pub const SMALL_RESOURCE_PLACEMENT_ALIGNMENT: Bytes =
-    Bytes(D3D12_SMALL_RESOURCE_PLACEMENT_ALIGNMENT as u64);
-pub const SO_BUFFER_MAX_STRIDE: Bytes =
-    Bytes(D3D12_SO_BUFFER_MAX_STRIDE_IN_BYTES as u64);
-pub const SO_BUFFER_MAX_WRITE_WINDOW: Bytes =
-    Bytes(D3D12_SO_BUFFER_MAX_WRITE_WINDOW_IN_BYTES as u64);
+pub const SMALL_MSAA_RESOURCE_PLACEMENT_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_SMALL_MSAA_RESOURCE_PLACEMENT_ALIGNMENT as u64);
+pub const SMALL_RESOURCE_PLACEMENT_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_SMALL_RESOURCE_PLACEMENT_ALIGNMENT as u64);
+pub const SO_BUFFER_MAX_STRIDE: ByteCount =
+    ByteCount(D3D12_SO_BUFFER_MAX_STRIDE_IN_BYTES as u64);
+pub const SO_BUFFER_MAX_WRITE_WINDOW: ByteCount =
+    ByteCount(D3D12_SO_BUFFER_MAX_WRITE_WINDOW_IN_BYTES as u64);
 pub const SO_BUFFER_SLOT_COUNT: u32 = D3D12_SO_BUFFER_SLOT_COUNT;
 pub const SO_DDI_REGISTER_INDEX_DENOTING_GAP: u32 =
     D3D12_SO_DDI_REGISTER_INDEX_DENOTING_GAP;
@@ -675,26 +668,26 @@ pub const TESSELLATOR_MIN_ODD_TESSELLATION_FACTOR: u32 =
     D3D12_TESSELLATOR_MIN_ODD_TESSELLATION_FACTOR;
 pub const TEXEL_ADDRESS_RANGE_BIT_COUNT: u32 =
     D3D12_TEXEL_ADDRESS_RANGE_BIT_COUNT;
-pub const TEXTURE_DATA_PITCH_ALIGNMENT: Bytes =
-    Bytes(D3D12_TEXTURE_DATA_PITCH_ALIGNMENT as u64);
-pub const TEXTURE_DATA_PLACEMENT_ALIGNMENT: Bytes =
-    Bytes(D3D12_TEXTURE_DATA_PLACEMENT_ALIGNMENT as u64);
-pub const TILED_RESOURCE_TILE_SIZE: Bytes =
-    Bytes(D3D12_TILED_RESOURCE_TILE_SIZE_IN_BYTES as u64);
+pub const TEXTURE_DATA_PITCH_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_TEXTURE_DATA_PITCH_ALIGNMENT as u64);
+pub const TEXTURE_DATA_PLACEMENT_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_TEXTURE_DATA_PLACEMENT_ALIGNMENT as u64);
+pub const TILED_RESOURCE_TILE_SIZE: ByteCount =
+    ByteCount(D3D12_TILED_RESOURCE_TILE_SIZE_IN_BYTES as u64);
 pub const TRACKED_WORKLOAD_MAX_INSTANCES: u32 =
     D3D12_TRACKED_WORKLOAD_MAX_INSTANCES;
-pub const UAV_COUNTER_PLACEMENT_ALIGNMENT: Bytes =
-    Bytes(D3D12_UAV_COUNTER_PLACEMENT_ALIGNMENT as u64);
+pub const UAV_COUNTER_PLACEMENT_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_UAV_COUNTER_PLACEMENT_ALIGNMENT as u64);
 pub const UAV_SLOT_COUNT: u32 = D3D12_UAV_SLOT_COUNT;
 pub const UNBOUND_MEMORY_ACCESS_RESULT: u32 =
     D3D12_UNBOUND_MEMORY_ACCESS_RESULT;
 pub const VIDEO_DECODE_MAX_ARGUMENTS: u32 = D3D12_VIDEO_DECODE_MAX_ARGUMENTS;
 pub const VIDEO_DECODE_MAX_HISTOGRAM_COMPONENTS: u32 =
     D3D12_VIDEO_DECODE_MAX_HISTOGRAM_COMPONENTS;
-pub const VIDEO_DECODE_MIN_BITSTREAM_OFFSET_ALIGNMENT: Bytes =
-    Bytes(D3D12_VIDEO_DECODE_MIN_BITSTREAM_OFFSET_ALIGNMENT as u64);
-pub const VIDEO_DECODE_MIN_HISTOGRAM_OFFSET_ALIGNMENT: Bytes =
-    Bytes(D3D12_VIDEO_DECODE_MIN_HISTOGRAM_OFFSET_ALIGNMENT as u64);
+pub const VIDEO_DECODE_MIN_BITSTREAM_OFFSET_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_VIDEO_DECODE_MIN_BITSTREAM_OFFSET_ALIGNMENT as u64);
+pub const VIDEO_DECODE_MIN_HISTOGRAM_OFFSET_ALIGNMENT: ByteCount =
+    ByteCount(D3D12_VIDEO_DECODE_MIN_HISTOGRAM_OFFSET_ALIGNMENT as u64);
 pub const VIDEO_PROCESS_MAX_FILTERS: u32 = D3D12_VIDEO_PROCESS_MAX_FILTERS;
 pub const VIDEO_PROCESS_STEREO_VIEWS: u32 = D3D12_VIDEO_PROCESS_STEREO_VIEWS;
 pub const VIEWPORT_AND_SCISSORRECT_MAX_INDEX: u32 =
